[patch] fortran/*.[ch]: Fix comment typos.

Kazu Hirata kazu@cs.umass.edu
Thu May 26 19:06:00 GMT 2005


Hi,

Committed as obvious.

Kazu Hirata

2005-05-26  Kazu Hirata  <kazu@cs.umass.edu>

	* data.c, parse.c, trans-array.c, trans-decl.c,
	trans-intrinsic.c, trans-stmt.c, trans-types.c, trans.c,
	trans.h: Fix comment typos.  Follow spelling conventions.

Index: fortran/data.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/data.c,v
retrieving revision 1.11
diff -u -d -p -r1.11 data.c
--- fortran/data.c	23 Jan 2005 14:36:24 -0000	1.11
+++ fortran/data.c	26 May 2005 18:30:42 -0000
@@ -132,7 +132,7 @@ find_con_by_component (gfc_component *co
 }
 
 
-/* Create a character type intialization expression from RVALUE.
+/* Create a character type initialization expression from RVALUE.
    TS [and REF] describe [the substring of] the variable being initialized.
    INIT is thh existing initializer, not NULL.  Initialization is performed
    according to normal assignment rules.  */
@@ -556,7 +556,7 @@ formalize_structure_cons (gfc_expr * exp
 
   c = expr->value.constructor;
 
-  /* Constructor is already fomalized.  */
+  /* Constructor is already formalized.  */
   if (c->n.component == NULL)
     return;
 
Index: fortran/parse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/parse.c,v
retrieving revision 1.26
diff -u -d -p -r1.26 parse.c
--- fortran/parse.c	15 Apr 2005 20:35:26 -0000	1.26
+++ fortran/parse.c	26 May 2005 18:30:43 -0000
@@ -2157,7 +2157,7 @@ gfc_fixup_sibling_symbols (gfc_symbol * 
             gfc_free_symbol (old_sym);
         }
 
-      /* Do the same for any contined procedures.  */
+      /* Do the same for any contained procedures.  */
       gfc_fixup_sibling_symbols (sym, ns->contained);
     }
 }
Index: fortran/trans-array.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-array.c,v
retrieving revision 1.43
diff -u -d -p -r1.43 trans-array.c
--- fortran/trans-array.c	29 Apr 2005 15:31:38 -0000	1.43
+++ fortran/trans-array.c	26 May 2005 18:30:45 -0000
@@ -4349,7 +4349,7 @@ gfc_walk_array_constructor (gfc_ss * ss,
 
 
 /* Walk an expression.  Add walked expressions to the head of the SS chain.
-   A wholy scalar expression will not be added.  */
+   A wholly scalar expression will not be added.  */
 
 static gfc_ss *
 gfc_walk_subexpr (gfc_ss * ss, gfc_expr * expr)
Index: fortran/trans-decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-decl.c,v
retrieving revision 1.58
diff -u -d -p -r1.58 trans-decl.c
--- fortran/trans-decl.c	10 May 2005 22:06:43 -0000	1.58
+++ fortran/trans-decl.c	26 May 2005 18:30:47 -0000
@@ -537,7 +537,7 @@ gfc_build_qualified_array (tree decl, gf
     {
       if (GFC_TYPE_ARRAY_LBOUND (type, dim) == NULL_TREE)
         GFC_TYPE_ARRAY_LBOUND (type, dim) = create_index_var ("lbound", nest);
-      /* Don't try to use the unkown bound for assumed shape arrays.  */
+      /* Don't try to use the unknown bound for assumed shape arrays.  */
       if (GFC_TYPE_ARRAY_UBOUND (type, dim) == NULL_TREE
           && (sym->as->type != AS_ASSUMED_SIZE
               || dim < GFC_TYPE_ARRAY_RANK (type) - 1))
Index: fortran/trans-intrinsic.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-intrinsic.c,v
retrieving revision 1.49
diff -u -d -p -r1.49 trans-intrinsic.c
--- fortran/trans-intrinsic.c	18 May 2005 13:57:48 -0000	1.49
+++ fortran/trans-intrinsic.c	26 May 2005 18:30:49 -0000
@@ -158,7 +158,7 @@ gfc_conv_intrinsic_function_args (gfc_se
   args = NULL_TREE;
   for (actual = expr->value.function.actual; actual; actual = actual->next)
     {
-      /* Skip ommitted optional arguments.  */
+      /* Skip omitted optional arguments.  */
       if (!actual->expr)
 	continue;
 
Index: fortran/trans-stmt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-stmt.c,v
retrieving revision 1.31
diff -u -d -p -r1.31 trans-stmt.c
--- fortran/trans-stmt.c	17 May 2005 06:31:51 -0000	1.31
+++ fortran/trans-stmt.c	26 May 2005 18:30:51 -0000
@@ -2965,7 +2965,7 @@ gfc_trans_where_assign (gfc_expr *expr1,
 
 
 /* Translate the WHERE construct or statement.
-   This fuction can be called iteratively to translate the nested WHERE
+   This function can be called iteratively to translate the nested WHERE
    construct or statement.
    MASK is the control mask, and PMASK is the pending control mask.
    TEMP records the temporary address which must be freed later.  */
Index: fortran/trans-types.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans-types.c,v
retrieving revision 1.44
diff -u -d -p -r1.44 trans-types.c
--- fortran/trans-types.c	17 May 2005 20:05:07 -0000	1.44
+++ fortran/trans-types.c	26 May 2005 18:30:52 -0000
@@ -1611,7 +1611,7 @@ gfc_get_function_type (gfc_symbol * sym)
 	     The problem arises if a function is called via an implicit
 	     prototype. In this situation the INTENT is not known.
 	     For this reason all parameters to global functions must be
-	     passed by reference.  Passing by value would potentialy
+	     passed by reference.  Passing by value would potentially
 	     generate bad code.  Worse there would be no way of telling that
 	     this code was bad, except that it would give incorrect results.
 
Index: fortran/trans.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans.c,v
retrieving revision 1.23
diff -u -d -p -r1.23 trans.c
--- fortran/trans.c	23 Mar 2005 11:09:24 -0000	1.23
+++ fortran/trans.c	26 May 2005 18:30:52 -0000
@@ -314,7 +314,7 @@ gfc_build_array_ref (tree base, tree off
 }
 
 
-/* Given a funcion declaration FNDECL and an argument list ARGLIST,
+/* Given a function declaration FNDECL and an argument list ARGLIST,
    build a CALL_EXPR.  */
 
 tree
Index: fortran/trans.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/fortran/trans.h,v
retrieving revision 1.26
diff -u -d -p -r1.26 trans.h
--- fortran/trans.h	1 Apr 2005 04:16:52 -0000	1.26
+++ fortran/trans.h	26 May 2005 18:30:52 -0000
@@ -251,8 +251,8 @@ gfc_saved_var;
 /* Advance the SS chain to the next term.  */
 void gfc_advance_se_ss_chain (gfc_se *);
 
-/* Call this to initialise a gfc_se structure before use
-   first parameter is structure to initialise, second is
+/* Call this to initialize a gfc_se structure before use
+   first parameter is structure to initialize, second is
    parent to get scalarization data from, or NULL.  */
 void gfc_init_se (gfc_se *, gfc_se *);
 



More information about the Gcc-patches mailing list